==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkGeoTerrain.java <==
// java wrapper for vtkGeoTerrain object
//

package vtk;
import vtk.*;

public class vtkGeoTerrain extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetSource_2();
  public vtkGeoSource GetSource() {
    long temp = GetSource_2();

    if (temp == 0) return null;
    return (vtkGeoSource)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetSource_3(vtkGeoSource id0);
  public void SetSource(vtkGeoSource id0)
    { SetSource_3(id0); }

  private native void SaveDatabase_4(String id0,int id1);
  public void SaveDatabase(String id0,int id1)
    { SaveDatabase_4(id0,id1); }

  private native void AddActors_5(vtkRenderer id0,vtkAssembly id1,vtkCollection id2);
  public void AddActors(vtkRenderer id0,vtkAssembly id1,vtkCollection id2)
    { AddActors_5(id0,id1,id2); }

  private native void SetOrigin_6(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_6(id0,id1,id2); }

  private native void SetOrigin_7(double id0[]);
  public void SetOrigin(double id0[])
    { SetOrigin_7(id0); }

  private native double[] GetOrigin_8();
  public double[] GetOrigin()
    { return GetOrigin_8(); }

  private native void SetMaxLevel_9(int id0);
  public void SetMaxLevel(int id0)
    { SetMaxLevel_9(id0); }

  private native int GetMaxLevelMinValue_10();
  public int GetMaxLevelMinValue()
    { return GetMaxLevelMinValue_10(); }

  private native int GetMaxLevelMaxValue_11();
  public int GetMaxLevelMaxValue()
    { return GetMaxLevelMaxValue_11(); }

  private native int GetMaxLevel_12();
  public int GetMaxLevel()
    { return GetMaxLevel_12(); }

  public vtkGeoTerrain() { super(); }

  public vtkGeoTerrain(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-9-aarch64.pkg.tar.xz: vtk/vtkGeoTerrain.java <==
// java wrapper for vtkGeoTerrain object
//

package vtk;
import vtk.*;

public class vtkGeoTerrain extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetSource_2();
  public vtkGeoSource GetSource() {
    long temp = GetSource_2();

    if (temp == 0) return null;
    return (vtkGeoSource)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSource_3(vtkGeoSource id0);
  public void SetSource(vtkGeoSource id0)
    { SetSource_3(id0); }

  private native void SaveDatabase_4(String id0,int id1);
  public void SaveDatabase(String id0,int id1)
    { SaveDatabase_4(id0,id1); }

  private native void AddActors_5(vtkRenderer id0,vtkAssembly id1,vtkCollection id2);
  public void AddActors(vtkRenderer id0,vtkAssembly id1,vtkCollection id2)
    { AddActors_5(id0,id1,id2); }

  private native void SetOrigin_6(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_6(id0,id1,id2); }

  private native void SetOrigin_7(double id0[]);
  public void SetOrigin(double id0[])
    { SetOrigin_7(id0); }

  private native double[] GetOrigin_8();
  public double[] GetOrigin()
    { return GetOrigin_8(); }

  private native void SetMaxLevel_9(int id0);
  public void SetMaxLevel(int id0)
    { SetMaxLevel_9(id0); }

  private native int GetMaxLevelMinValue_10();
  public int GetMaxLevelMinValue()
    { return GetMaxLevelMinValue_10(); }

  private native int GetMaxLevelMaxValue_11();
  public int GetMaxLevelMaxValue()
    { return GetMaxLevelMaxValue_11(); }

  private native int GetMaxLevel_12();
  public int GetMaxLevel()
    { return GetMaxLevel_12(); }

  public vtkGeoTerrain() { super(); }

  public vtkGeoTerrain(long id) { super(id); }
  public native long   VTKInit();

}
